int add2history(char *path);
int open_history(GtkTreeView * treeview, GtkTreeIter * iter, GtkTreePath * treepath, gpointer user_data);


